config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    rm $NEW
  fi
}

config etc/sun/sun.toml.new

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications >/dev/null 2>&1
fi

for file in sun_daemon.desktop ; do
  cmp etc/xdg/autostart/${file} etc/xdg/autostart/${file}.sample 2> /dev/null && \
	rm etc/xdg/autostart/${file}.sample
done
